//DATABEHANDLING OG FILTRERING//

*Importerer fil "rådata markedsverdier"
use "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\rådata markedsverdier.dta"

*Rename variabler etter ønske
ren TickerSymbol ticker
ren PriceorBidAskAverage price
ren SharesOutstanding numberofshares

*Fjerner observasjoer som mangler vesentlige poster
drop if ticker==""
drop if CompanyName==""
drop if price==.
drop if numberofshares==.

*Generere year variabel
gen year=int( NamesDate/10000)

*Multiplisere antall utestående aksjer med 1000
gen antallaksjer= numberofshares*1000

*Fjerner observasjoner med negativ pris da dette indikerer en bid/ask pris
drop if price<0

*Kapitiliserer 
gen MVek=antallaksjer*price

*Beregner snitt per år og fjerner duplikater
by ticker year, sort: egen mean2=mean(MVek)
quietly by ticker year:  gen dup = cond(_N==1,0,_n)
drop if dup>1
drop dup
ren mean2 MVEK

*Lagre som "markedsverdier klar til merge" og lukk fil
save "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\markedsverdier klar til merge.dta", replace
clear all

*Åpne betaverdier fra NYSE og AMEX
use "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\rådata betaverdier NYSE AMEX.dta"

*Skøyt sammen med betaverdier fra NASDAQ
append using "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Klargjøring av markedsverdier STATA/rådata betaverdier NASDAQ"

*Rename i henhold til fil med markedsverdier
ren TickerSymbol ticker
ren Year year

*Fjerner unødvendige variabler og observasjoner som mangler vesentlig informasjon
drop CRSPPERMNO BetaPortfolioAssignment PortfolioType Date
drop if ticker==""
drop if Beta==0

*Merge med markedsverdier
merge m:1 year ticker using "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse/markedsverdier klar til merge", keep(match) nogenerate


*Sørger for at det bare ligger en observasjon per år
sort year ticker
quietly by year ticker:  gen dup = cond(_N==1,0,_n)
drop if dup>1
drop dup

*Lagre som markedsverdier og betaverdier klar til merge" og lukk fil
save "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\markedsverdier og betaverdier klar til merge.dta", replace
clear all

*Importer regnskapstall
use "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\rådata regnskapstall.dta"

*Rename i henhold til fil med betaverdier og markedsverdier, og sørger for at det bare ligger en observasjon per år
ren TickerSymbol ticker
ren DataYearFiscal year
sort year ticker
quietly by year ticker:  gen dup = cond(_N==1,0,_n)
drop if dup>1
drop dup

*Merge med betaverdier og markedsverdier
merge m:1 year ticker using "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse/markedsverdier og betaverdier klar til merge", keep(match) nogenerate

*Dropper variabler som mangler vesentlige poster
drop if StockholdersEquityTotal==.
drop if LiabilitiesTotal==.
drop if NetIncomeLoss ==.
drop if InterestandRelatedExpenseT ==.
drop if SalesTurnoverNet ==0
drop if IncomeTaxesTotal==.
drop if PretaxIncome ==0

*Dropper variabler som gir misvisende eller udefinerte tall
drop if StockholdersEquityTotal<0 & NetIncomeLoss<0
drop if LiabilitiesTotal==0 & InterestandRelatedExpenseT!=0


*Multipliserer regnskapstall med 1000000
gen totaleeiendeler= AssetsTotal*1000000
gen totalgjeld= LiabilitiesTotal *1000000
gen resultat= NetIncomeLoss *1000000
gen resultatfskatt=  PretaxIncome *1000000
gen omsetning=  SalesTurnoverNet *1000000
gen BVEK=  StockholdersEquityTotal *1000000
gen skattekostnad=  IncomeTaxesTotal *1000000
gen rentekostnader= InterestandRelatedExpenseT*1000000

*Genererer variablene
gen BVroe = resultat / BVEK
gen MVroe= resultat/ MVEK
gen BVroa=( resultatfskatt+ rentekostnader)/( totalgjeld +BVEK)
gen MVroa=( resultatfskatt+ rentekostnader)/( totalgjeld + MVEK )
gen skattesats= skattekostnad /resultatfskatt
gen gjeldskostnad= rentekostnader/ totalgjeld
replace gjeldskostnad=0 if gjeldskostnad==.
gen BVgjeldsgrad= totalgjeld/ BVEK
gen MVgjeldsgrad= totalgjeld/ MVEK
gen BVgjeldsandel= totalgjeld/ (BVEK+ totalgjeld)
gen MVgjeldsandel= totalgjeld/ (MVEK+ totalgjeld)
gen BVWACC= (BVEK/( BVEK+ totalgjeld))* BVroe+ BVgjeldsandel* gjeldskostnad*(1- skattesats)
gen MVWACC= (MVEK/( MVEK+ totalgjeld))* MVroe+ MVgjeldsandel* gjeldskostnad*(1- skattesats)
gen Bua= Beta/(1+(1- skattesats)* BVgjeldsgrad)
gen rua= BVWACC/(1- skattesats*BVgjeldsandel)
gen FM= resultat/ omsetning
gen KOMLH= omsetning/ totaleeiendeler
gen EM= totaleeiendeler/ BVEK


*Beregner gjennomsnitt per selskaper
egen tag=tag(ticker Beta)
egen betam=mean(cond(tag, Beta,.)), by(ticker)
egen tag1=tag(ticker BVroe )
egen BVroem=mean(cond(tag1, BVroe,.)), by(ticker)
egen tag2=tag(ticker MVroe )
egen MVroem=mean(cond(tag2, MVroe,.)), by(ticker)
egen tag3=tag(ticker BVroa )
egen BVroam=mean(cond(tag3, BVroa,.)), by(ticker)
egen tag4=tag(ticker MVroa )
egen MVroam=mean(cond(tag4, MVroa,.)), by(ticker)
egen tag5=tag(ticker skattesats )
egen skattesatsm=mean(cond(tag5, skattesats,.)), by(ticker)
egen tag6=tag(ticker gjeldskostnad )
egen gjeldskostnadm =mean(cond(tag6, gjeldskostnad ,.)), by(ticker)
egen tag7=tag(ticker BVgjeldsgrad )
egen BVgjeldsgradm =mean(cond(tag7, BVgjeldsgrad ,.)), by(ticker)
egen tag8=tag(ticker MVgjeldsgrad )
egen MVgjeldsgradm =mean(cond(tag8, MVgjeldsgrad ,.)), by(ticker)
egen tag9=tag(ticker BVgjeldsandel )
egen BVgjeldsandelm =mean(cond(tag9, BVgjeldsandel ,.)), by(ticker)
egen tag10=tag(ticker MVgjeldsandel )
egen MVgjeldsandelm =mean(cond(tag10, MVgjeldsandel ,.)), by(ticker)
egen tag11=tag(ticker BVWACC )
egen BVWACCm =mean(cond(tag11, BVWACC ,.)), by(ticker)
egen tag12=tag(ticker MVWACC )
egen MVWACCm =mean(cond(tag12, MVWACC ,.)), by(ticker)
egen tag13=tag(ticker Bua )
egen Buam =mean(cond(tag13, Bua ,.)), by(ticker)
egen tag14=tag(ticker rua )
egen ruam =mean(cond(tag14, rua ,.)), by(ticker)
egen tag15=tag(ticker FM )
egen FMm =mean(cond(tag15, FM ,.)), by(ticker)
egen tag16=tag(ticker KOMLH )
egen KOMLHm =mean(cond(tag16, KOMLH ,.)), by(ticker)
egen tag17=tag(ticker EM )
egen EMm =mean(cond(tag17, EM ,.)), by(ticker)

*Fjerner duplikater
sort year
sort ticker
quietly by ticker:  gen dup = cond(_N==1,0,_n)
drop if dup>1

*Dropper variabler som ikke benyttes i analysen
drop StandardandPoorsIdentifier DataDate IndustryFormat LevelofConsolidationCompany PopulationSource DataFormat CompanyName ISOCurrencyCode AssetsTotal LiabilitiesTotal NetIncomeLoss PretaxIncome SalesTurnoverNet StockholdersEquityTotal IncomeTaxesTotal InterestandRelatedExpenseT ActiveInactiveStatusMarker Beta PERMNO NamesDate price numberofshares antallaksjer MVek MVEK totaleeiendeler totalgjeld resultat resultatfskatt omsetning BVEK skattekostnad rentekostnader BVroe MVroe BVroa MVroa skattesats gjeldskostnad BVgjeldsgrad MVgjeldsgrad BVgjeldsandel MVgjeldsandel BVWACC MVWACC Bua rua FM KOMLH EM tag tag1 tag2 tag3 tag4 tag5 tag6 tag7 tag8 tag9 tag10 tag11 tag12 tag13 tag14 tag15 tag16 tag17 dup

ren betam beta
ren BVroem BVroe
ren MVroem MVroe
ren BVroam BVroa
ren MVroam MVroa
ren skattesatsm skattesats
ren gjeldskostnadm gjeldskostnad
ren BVgjeldsgradm BVgjeldsgrad
ren MVgjeldsgradm MVgjeldsgrad
ren BVgjeldsandelm BVgjeldsandel
ren MVgjeldsandelm MVgjeldsandel
ren BVWACCm BVWACC
ren MVWACCm MVWACC
ren Buam Bua
ren ruam rua
ren FMm FM
ren KOMLHm KOMLH
ren EMm EM

*Lagrer som "Variabler før fjerning av ekstremverdier"
save "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\Variabler før fjerning av ekstremverdier.dta",replace

*Fjerner ekstremverdier (slakkere betingelser)
drop if BVgjeldsgrad >100
drop if BVgjeldsgrad <-100
drop if BVroe >10
drop if BVroe <-10
drop if BVWACC > 10

*Lagrer som "Variabler etter fjerning av ekstremverdier - slakkere betingelser"
save "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\Variabler etter fjerning av ekstremverdier - slakkere betingelser.dta", replace

*Fjerner ekstremverdier
drop if BVgjeldsgrad >20
drop if BVgjeldsgrad <-10
drop if BVroe >2
drop if BVroe <-1
drop if BVroa >2
drop if BVroa <-1
drop if BVWACC >2
drop if BVWACC <-1
drop if BVgjeldsandel >1
drop if BVgjeldsandel <0
drop if gjeldskostnad>1
drop if beta>3.4
drop if skattesats>2
drop if skattesats<-2
drop if FM>2
drop if FM<-2
drop if MVgjeldsgrad>20
drop if MVroe>2
drop if MVroe<-1
sum, det

//INNDELING I RISIKOKLASSER//
gen riskclass=.
replace riskclass=0 if beta<0
replace riskclass=1 if beta>=0 & beta<0.5
replace riskclass=2 if beta>=0.5 & beta<1
replace riskclass=3 if beta>=1 & beta<1.5
replace riskclass=4 if beta>=1.5 & beta<2
replace riskclass=5 if beta>=2 & beta<3.4

*Lagrer som "Variabler etter fjerning av ekstremverdier - fullstendig"
save "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\Variabler etter fjerning av ekstremverdier - fullstendig.dta",replace

//ANALYSE MED TRENDLINJER//
*Alle risikoklasser samlet
sum,det
**Lineær trendlinje med bokførte verdier
reg BVroe BVgjeldsgrad
reg BVroa BVgjeldsgrad
reg BVWACC BVgjeldsgrad
reg gjeldskostnad BVgjeldsgrad
**Lineær trendlinje i henhold til MM2
gen roeteori=BVroa+BVgjeldsgrad*(BVroa-gjeldskostnad)
reg roeteori BVgjeldsgrad
**Lineær trendlinje med markedsverdier
reg MVroe MVgjeldsgrad
reg MVroa MVgjeldsgrad
reg MVWACC MVgjeldsgrad
reg gjeldskostnad MVgjeldsgrad
**Polynom trendlinje med bokførte verdier
gen gjeldsandelsq=BVgjeldsandel^2
reg BVroe gjeldsandelsq BVgjeldsandel 
reg BVroa gjeldsandelsq BVgjeldsandel 
reg BVWACC gjeldsandelsq BVgjeldsandel 
reg gjeldskostnad gjeldsandelsq BVgjeldsandel
*Unlevered avkastning
reg rua BVgjeldsgrad
*Regresjon med færre begrensninger
clear all
use "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\Variabler etter fjerning av ekstremverdier - slakkere betingelser.dta"
reg BVroe BVgjeldsgrad
reg BVroa BVgjeldsgrad
reg BVWACC BVgjeldsgrad
reg gjeldskostnad BVgjeldsgrad
gen gjeldsandelsq=BVgjeldsandel^2
reg BVroe gjeldsandelsq BVgjeldsandel 
reg BVroa gjeldsandelsq BVgjeldsandel 
reg BVWACC gjeldsandelsq BVgjeldsandel 
reg gjeldskostnad gjeldsandelsq BVgjeldsandel
clear all

*Risikoklasse 0
use "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\Variabler etter fjerning av ekstremverdier - fullstendig.dta"
drop if riskclass>0
sum,det
**Lineær trendlinje med bokførte verdier
reg BVroe BVgjeldsgrad
reg BVroa BVgjeldsgrad
reg BVWACC BVgjeldsgrad
reg gjeldskostnad BVgjeldsgrad
**Lineær trendlinje i henhold til MM2
gen roeteori=BVroa+BVgjeldsgrad*(BVroa-gjeldskostnad)
reg roeteori BVgjeldsgrad
**Lineær trendlinje med markedsverdier
reg MVroe MVgjeldsgrad
reg MVroa MVgjeldsgrad
reg MVWACC MVgjeldsgrad
reg gjeldskostnad MVgjeldsgrad
**Polynom trendlinje med bokførte verdier
gen gjeldsandelsq=BVgjeldsandel^2
reg BVroe gjeldsandelsq BVgjeldsandel 
reg BVroa gjeldsandelsq BVgjeldsandel 
reg BVWACC gjeldsandelsq BVgjeldsandel 
reg gjeldskostnad gjeldsandelsq BVgjeldsandel
save "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\risikoklasse 0.dta",replace
clear all

*Risikoklasse 1
use "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\Variabler etter fjerning av ekstremverdier - fullstendig.dta"
drop if riskclass<1 
drop if riskclass>1
sum,det
**Lineær trendlinje med bokførte verdier
reg BVroe BVgjeldsgrad
reg BVroa BVgjeldsgrad
reg BVWACC BVgjeldsgrad
reg gjeldskostnad BVgjeldsgrad
**Lineær trendlinje i henhold til MM2
gen roeteori=BVroa+BVgjeldsgrad*(BVroa-gjeldskostnad)
reg roeteori BVgjeldsgrad
**Lineær trendlinje med markedsverdier
reg MVroe MVgjeldsgrad
reg MVroa MVgjeldsgrad
reg MVWACC MVgjeldsgrad
reg gjeldskostnad MVgjeldsgrad
**Polynom trendlinje med bokførte verdier
gen gjeldsandelsq=BVgjeldsandel^2
reg BVroe gjeldsandelsq BVgjeldsandel 
reg BVroa gjeldsandelsq BVgjeldsandel 
reg BVWACC gjeldsandelsq BVgjeldsandel 
reg gjeldskostnad gjeldsandelsq BVgjeldsandel
save "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\risikoklasse 1.dta",replace
clear all

*Risikoklasse 2
use "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\Variabler etter fjerning av ekstremverdier - fullstendig.dta"
drop if riskclass<2
drop if riskclass>2
sum,det
**Lineær trendlinje med bokførte verdier
reg BVroe BVgjeldsgrad
reg BVroa BVgjeldsgrad
reg BVWACC BVgjeldsgrad
reg gjeldskostnad BVgjeldsgrad
**Lineær trendlinje i henhold til MM2
gen roeteori=BVroa+BVgjeldsgrad*(BVroa-gjeldskostnad)
reg roeteori BVgjeldsgrad
**Lineær trendlinje med markedsverdier
reg MVroe MVgjeldsgrad
reg MVroa MVgjeldsgrad
reg MVWACC MVgjeldsgrad
reg gjeldskostnad MVgjeldsgrad
**Polynom trendlinje med bokførte verdier
gen gjeldsandelsq=BVgjeldsandel^2
reg BVroe gjeldsandelsq BVgjeldsandel 
reg BVroa gjeldsandelsq BVgjeldsandel 
reg BVWACC gjeldsandelsq BVgjeldsandel 
reg gjeldskostnad gjeldsandelsq BVgjeldsandel 
save "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\risikoklasse 2.dta",replace
clear all

*Risikoklasse 3
use "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\Variabler etter fjerning av ekstremverdier - fullstendig.dta"
drop if riskclass<3 
drop if riskclass>3
sum,det
**Lineær trendlinje med bokførte verdier
reg BVroe BVgjeldsgrad
reg BVroa BVgjeldsgrad
reg BVWACC BVgjeldsgrad
reg gjeldskostnad BVgjeldsgrad
**Lineær trendlinje i henhold til MM2
gen roeteori=BVroa+BVgjeldsgrad*(BVroa-gjeldskostnad)
reg roeteori BVgjeldsgrad
**Lineær trendlinje med markedsverdier
reg MVroe MVgjeldsgrad
reg MVroa MVgjeldsgrad
reg MVWACC MVgjeldsgrad
reg gjeldskostnad MVgjeldsgrad
**Polynom trendlinje med bokførte verdier
gen gjeldsandelsq=BVgjeldsandel^2
reg BVroe gjeldsandelsq BVgjeldsandel 
reg BVroa gjeldsandelsq BVgjeldsandel 
reg BVWACC gjeldsandelsq BVgjeldsandel 
reg gjeldskostnad gjeldsandelsq BVgjeldsandel
save "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\risikoklasse 3.dta",replace
clear all

*Risikoklasse 4
use "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\Variabler etter fjerning av ekstremverdier - fullstendig.dta"
drop if riskclass<4 
drop if riskclass>4
sum,det
**Lineær trendlinje med bokførte verdier
reg BVroe BVgjeldsgrad
reg BVroa BVgjeldsgrad
reg BVWACC BVgjeldsgrad
reg gjeldskostnad BVgjeldsgrad
**Lineær trendlinje i henhold til MM2
gen roeteori=BVroa+BVgjeldsgrad*(BVroa-gjeldskostnad)
reg roeteori BVgjeldsgrad
**Lineær trendlinje med markedsverdier
reg MVroe MVgjeldsgrad
reg MVroa MVgjeldsgrad
reg MVWACC MVgjeldsgrad
reg gjeldskostnad MVgjeldsgrad
**Polynom trendlinje med bokførte verdier
gen gjeldsandelsq=BVgjeldsandel^2
reg BVroe gjeldsandelsq BVgjeldsandel 
reg BVroa gjeldsandelsq BVgjeldsandel 
reg BVWACC gjeldsandelsq BVgjeldsandel 
reg gjeldskostnad gjeldsandelsq BVgjeldsandel
save "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\risikoklasse 4.dta",replace
clear all

*Risikoklasse 5
use "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse/Variabler etter fjerning av ekstremverdier - fullstendig.dta"
drop if riskclass<5 
drop if riskclass>5
sum,det
**Lineær trendlinje med bokførte verdier
reg BVroe BVgjeldsgrad
reg BVroa BVgjeldsgrad
reg BVWACC BVgjeldsgrad
reg gjeldskostnad BVgjeldsgrad
**Lineær trendlinje i henhold til MM2
gen roeteori=BVroa+BVgjeldsgrad*(BVroa-gjeldskostnad)
reg roeteori BVgjeldsgrad
**Lineær trendlinje med markedsverdier
reg MVroe MVgjeldsgrad
reg MVroa MVgjeldsgrad
reg MVWACC MVgjeldsgrad
reg gjeldskostnad MVgjeldsgrad
**Polynom trendlinje med bokførte verdier
gen gjeldsandelsq=BVgjeldsandel^2
reg BVroe gjeldsandelsq BVgjeldsandel 
reg BVroa gjeldsandelsq BVgjeldsandel 
reg BVWACC gjeldsandelsq BVgjeldsandel 
reg gjeldskostnad gjeldsandelsq BVgjeldsandel 
save "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\risikoklasse 5.dta",replace
clear all

//DELER INN I RISIKOKLASSER BASERT PÅ GJELDSJUSTERT BETA
use "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\Variabler etter fjerning av ekstremverdier - fullstendig.dta"
gen riskclassbua=.
replace riskclassbua=0 if Bua<0
replace riskclassbua=1 if Bua>=0 & Bua<0.5
replace riskclassbua=2 if Bua>=0.5 & Bua<1
replace riskclassbua=3 if Bua>=1 & Bua<1.5
replace riskclassbua=4 if Bua>=1.5 & Bua<2
replace riskclassbua=5 if Bua>=2 

*Deskriptiv statistikk
sum Bua BVroe BVgjeldsgrad rua if riskclassbua==0, det
sum Bua BVroe BVgjeldsgrad rua if riskclassbua==1, det
sum Bua BVroe BVgjeldsgrad rua if riskclassbua==2, det
sum Bua BVroe BVgjeldsgrad rua if riskclassbua==3, det
sum Bua BVroe BVgjeldsgrad rua if riskclassbua==4, det
sum Bua BVroe BVgjeldsgrad rua if riskclassbua==5, det

//ANALYSE VED BRUK AV BLINDER-OAXACA DECOMPOSITION
*Åpner ferdigfiltrert utvalg
use "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\Variabler etter fjerning av ekstremverdier - fullstendig.dta"

*Genererer tre grupper med hhv. høy (1), middels (2) og lav (3)
gen groupvar=.
replace groupvar=1 if BVgjeldsandel >=0.6
replace groupvar=2 if BVgjeldsandel >=0.4 & BVgjeldsandel <0.6
replace groupvar=3 if BVgjeldsandel <0.4


*Lagrer som "Kjøreklar Blinder-Oaxaca"
save "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\kjøreklar Blinder-Oaxaca.dta",replace

*Kjører for gruppe 1 og 3 (høy og lav)
drop if groupvar==2
oaxaca BVroe FM KOMLH , by( groupvar) noisily
clear all

*Kjører for gruppe 2 og 3 (middels og lav)
use "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\kjøreklar Blinder-Oaxaca.dta"
drop if groupvar==1
oaxaca BVroe FM KOMLH , by( groupvar) noisily
clear all

*Kjører for gruppe 1 og 2 (høy og middels)
use "C:\Users\bruker\OneDrive\Documents\Masteroppgave\Beregninger fra rådata til analyse\kjøreklar Blinder-Oaxaca.dta"
drop if groupvar==3
oaxaca BVroe FM KOMLH , by( groupvar) noisily
clear all
